<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
                      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">

  <xi:include href="master.html" />

<head>
  <meta content="text/html; charset=UTF-8" http-equiv="Content-Type" py:if="False"/>
  <title>${page.title}</title>
</head>

<body>
  <div class="flatpages-page">
    <div class="page-header">
      <h1>${page.title}</h1>
    </div>

    <div class="page-content">
      <p>${Markup(page.html_content)}</p>
    </div>
  </div>
</body>
</html>
